@@ -38,6 +38,9 @@ class Client(metaclass=abc.ABCMeta):
     async def post(self, *args, **kwargs):
         return await self.request(self.session.post, *args, **kwargs)
 
+    async def put(self, *args, **kwargs):
+        return await self.request(self.session.put, *args, **kwargs)
+
     async def __aenter__(self):
         self.session = await self.credentials.apply(self.audience, self.scope)
         await self.session.__aenter__()
